@@ -36,6 +36,8 @@ const QString stateStr[modeBase::MBTXGAPROBOT+1]=
   "ENDOFLINE",
   "EOIMAGE",
   "RXWAIT",
+  "MB1500",
+  "MB2300",
   "TXGAP",
   "TXGAPROBOT"
 };
@@ -171,7 +173,7 @@ void modeBase::redrawFast(bool r)
     }
 }
 
-modeBase::eModeBase modeBase::process(quint16 *demod,unsigned int syncPos,bool goToSync)
+modeBase::eModeBase modeBase::process(quint16 *demod,unsigned int syncPos,bool goToSync,unsigned int rxPos)
 {
   unsigned int i=0;
   if(goToSync)
@@ -247,9 +249,11 @@ modeBase::eModeBase modeBase::process(quint16 *demod,unsigned int syncPos,bool g
             if(sampleCounter>=marker)
               {
                 avgFreqGap/=avgFreqGapCounter;
+                addToLog(QString("GapCounter1 %1 at %2").arg(avgFreqGap).arg(sampleCounter),LOGMODES);
                 if(avgFreqGap > 1900)
                   {
-                    //                    subLine=10;
+                    qDebug() << "switching to 2300"<< QString("GapCounter2 %1 at %2").arg(avgFreqGap).arg(i+ rxPos);
+                    subLine=10;
                   }
                 switchState(MBSETUPLINE);
               }
@@ -266,9 +270,11 @@ modeBase::eModeBase modeBase::process(quint16 *demod,unsigned int syncPos,bool g
             if(sampleCounter>=marker)
               {
                 avgFreqGap/=avgFreqGapCounter;
+                addToLog(QString("GapCounter2 %1 at %2").arg(avgFreqGap).arg(sampleCounter),LOGMODES);
                 if(avgFreqGap < 1900)
                   {
-                    //                    subLine=3;
+                    qDebug() << "switching to 1500" << QString("GapCounter2 %1 at %2").arg(avgFreqGap).arg(i+ rxPos);
+                    subLine=3;
                   }
                 switchState(MBSETUPLINE);
               }
@@ -383,6 +389,9 @@ void modeBase::yuvConversion(unsigned char *array)
       r=(100*array[i]+140*redArrayPtr[i]-17850)/100;
       b=(100*array[i]+178*blueArrayPtr[i]-22695)/100;
       g=(100*array[i]- 71*redArrayPtr[i]-33*blueArrayPtr[i]+13260)/100;
+//      r=b=g=array[i]; //test
+
+
       r=(r>255 ? 255 : r);
       r=(r<0 ? 0 : r);
       b=(b>255 ? 255 : b);
@@ -398,11 +407,14 @@ modeBase::eModeBase modeBase::transmitImage(imageViewer *iv)
 {
   txImPtr=iv;
   if(!iv->hasValidImage()) return MBENDOFIMAGE;
+  addToLog(QString("Starting Transmit Image"),LOGMODES);
   displayLineCounter=0;
   lineCounter=0;
+  sampleCounter=0;
   getLine();
   state=MBSETUPLINE;
   start=0;
+  subLine=0;
   abortRun=false;
   while(!abortRun)
     {
@@ -590,6 +602,8 @@ void modeBase::getLine()
   //      .arg(QString::number((ulong)redArrayPtr,16))
   //      .arg(QString::number((ulong)blueArrayPtr,16)),LOGMODES);
   unsigned int *pixelArray=txImPtr->getScanLineAddress(displayLineCounter);
+
+
   for (unsigned int i=0;i<activeSSTVParam->numberOfPixels;i++)
     {
       t=pixelArray[i];
@@ -605,6 +619,6 @@ void modeBase::getLine()
 
 void modeBase::switchState(embState  newState)
 {
-  addToLog(QString("%1 to %2").arg(stateStr[state]).arg(stateStr[newState]),LOGMODES);
+//  addToLog(QString("%1 to %2").arg(stateStr[state]).arg(stateStr[newState]),LOGMODES);
   state=newState;
 }
