@@ -41,8 +41,7 @@
 #include <math.h>
 #include <assert.h>
 
-//#include "opj_apps_config.h"
-#include "openjpeg-2.1/openjpeg.h"
+#include "openjpeg.h"
 #include "color.h"
 
 
